#delimit;
capture log close;
log using c:\data\bulg\skouf97\log\clcexp01,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP01.DO              V : 01              *;
*    Date    : May 22,1998                                  *;
*    Infile  : FILE11V1b, CONMILK, GITEMF                   *;
*    Outfile : FOODEXP0, HHEXPF                             *;
*    Author  : C. del Ninno /Mamta Murthi                   *;
*                                                           *;
*    OBJECTIVE: Collapse the data for the food expenditure  *;
*               file into fewer categories with info        *;
*               on prices and share of food produced        *;
*                                                           *;
*************************************************************;
clear;
set more 1;
use file11v1b;

** CHECK CONSISTENCY AMONG PRICES REPORTED AND PRICES ASSUMED
*  Which prices to use to calculate total expenditure? ;

** From previous analysis it is obvious that most price are exactly 
    the same as reported for actual and for supposed. There are some 
    prices that are different, mostly because some of them are outliers. 
    In this case we set a simple rule for deleting 
    outliers and using medians to replace missing values.  
    The steps are the following:
 
    a) Set all prices (actual and assumed) to missing if they are 
       larger than three times the mean or the mean plus
       2 times the standard deviation.
    b) Use the assumed price if available, otherwise 
    c) Use Actual price if available
    d) Use the median price by District and rural urban if available
 
** Calculate price means and standard deviations
 ;
egen mprice=mean(pricenow), by(item);
egen sprice=sd(pricenow), by(item);
egen mpprice=mean(p_price), by(item);
egen spprice=sd(p_price), by(item);

** Outliers are defined as larger than 3 times the mean or 
    the mean + 2 times the standard deviation or less than the mean 
    minus 2 times the standard deviation.  In this way only highly
    unlikely prices are eliminated. 
 ;
gen outera1=1 if pricenow>mprice+sprice*2 & price~=.;
gen outera2=1 if p_price>mpprice+spprice*2 & p_price~=.;
gen outerb1=1 if pricenow>mprice*3 & price~=.;
gen outerb2=1 if p_price>mpprice*3 & p_price~=.;
gen lower1=1  if pricenow<mprice-sprice*2 ;
gen lower2=1  if p_price<mpprice-spprice*2 ;

tab item if outera2==1 & outerb2==1 | lower2==1;

replace price=.   if (outera1==1 & outerb1==1) | lower1==1 ;
replace p_price=. if (outera2==1 & outerb1==1) | lower2==1 ;

drop p_t p_v p_pur mp* sp* outer* lower*;

sort hhnum;

merge hhnum using strata;
tab _merge;

list hhnum if _merge==1;
list hhnum if _merge==2;

keep if _merge==3;

drop _merge region clust day* month2 pop* lang;

** calculate median prices
;
egen mdpri1=median(pricenow), by(item dist loc_ty);
egen mdpri2=median(pricenow), by(item);

** Calculate price & price index variables - 
   Price index for each item & Hh is calculated dividing by the 
   mean
;
gen prix=pricenow;
replace prix=p_price if prix==.;
replace prix=mdpri1 if prix==.;
replace prix=mdpri2 if prix==.;

egen mprix=mean(prix), by(item);
gen pindex=prix/mprix;
lab var pindex "Price Index";
drop pricenow p_price md* mprix;
sum item c_tot prix pindex;

tab item, sum(prix);
count if pindex>5;

**  CHECK CONSISTENCY AMONG QUANTITIES REPORTED 
**  Total food expenditure is estimated as the quantity consumed 
    times the price - See price discussion above.
 
     First we will chech for the existence of outliers on a per capita 
     quantity basis.  Then we will calculate the value and 
     aggregate over fewer commodity groups. - 
     Price indices would be welcome but for the time being....
;
**  We checked for the possibility of double counting in the case
    of the production of processed food commodities.  That they would 
    report the consumption of sugar used for the preparation of 
    liquor and the consumption of liquor itself.  After carefull
    checking we concluded that the only serious overreporting could 
    occur only in the case of milk and milk products.  In fact the 
    mean of the fresh milk consumption was approximately 2.6 times as high 
    if the household reported consumption of own produced white cheese
    and/or yogurt.  The details of the calculation (affecting a total
    of 208 households consuming more than 10 liters of milk a month)
    is included in the program EXP11D.DO.
;    
replace c_tot=c_tot*4.2 if c_tu==1;  /* Report data on Monthly basis */
replace c_pur=c_pur*4.2 if c_tu==1;  /* Report data on Monthly basis */
replace c_rec=c_rec*4.2 if c_tu==1;  /* Report data on Monthly basis */
replace c_own=c_own*4.2 if c_tu==1;  /* Report data on Monthly basis */

** Replace milk quantities with adjusted quantities to take into
   account the possibility of double coounting 
;
sort hhnum;
merge hhnum using conmilk;
replace c_tot=cmilk if cmilk~=. & item==801;
drop cmilk _merge;

** Check and replace outliers;
* Bring in the household size
;
sort hhnum;
merge hhnum using hhsize;

tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;

gen pcqua=c_tot/hhsizer;

** Calculate quantities means and standard deviations;

egen mpcqua=mean(pcqua), by(item);
egen spcqua=sd(pcqua)  , by(item);

** Outliers are defined as larger than 5 times the mean and larger than
    the mean + 3 times the standard deviation.  In this way only very 
    improbable numbers are eliminated (note the conditions are far less
    stringent now than in the case of prices). 
;
gen outq1=1 if pcqua>mpcqua+spcqua*3 & pcqua~=.;
gen outq2=1 if pcqua>mpcqua*5 & pcqua~=.;

format pcq %5.2f;

tab item, sum(pcq);
tab item if outq1==1 & outq2==1;


** Calculate median values;

egen mdpcq1=median(pcq), by(item dist loc_ty);
egen mdpcq2=median(pcq), by(item);

* Calculate the quantity variable and set missing values
;
gen quant=c_tot;

replace quant=. if outq1==1 & outq2==1;
replace quant=mdpcq1*hhsizer if quant==.;
replace quant=mdpcq2*hhsizer if quant==.;

sort item;
merge item using gitemf;

gen totexp=quant*prix;

** Calculate shares of food from own production and/or received 
   from other sources
;
gen sharqown=0;
lab var sharqown "Share Own Production";
gen sharqrec=0;
lab var sharqrec "Share Received";
format shar* %5.2f;

gen pos_p =c_pur>0 & c_pur~=.;
gen pos_r =c_rec>0 & c_rec~=.;
gen pos_o =c_own>0 & c_own~=.;

sum pos_*;
tab pos_r pos_o if pos_p==0;
tab pos_r pos_o if pos_p==1;

replace sharqrec=100 if pos_r==1 & pos_p==0 & pos_o==0;
replace sharqown=100 if pos_o==1 & pos_p==0 & pos_r==0;

replace sharqrec=100*c_rec/c_tot if pos_r==1 &
                                    (pos_p==1 & (pos_o==0 | pos_o==1)); 
replace sharqown=100*c_own/c_tot if pos_o==1 &
                                    (pos_p==1 & (pos_r==0 | pos_r==1));
            
** After observations shares of missing values have been left at zero
   There are 60 missing values, mostly food away from home, spices 
   and salt
;
tab item, sum(sharqr);
tab item, sum(sharqo);
tab item if sharqr==.;
replace sharqrec=. if (pos_p==0 & pos_r==0 & pos_o==0) | c_tot==0 ;
replace sharqown=. if (pos_p==0 & pos_r==0 & pos_o==0) | c_tot==0 ;
;
keep hhnum item g_item quant prix pindex totexp dist loc_ty shar*;

** Calculate Budget shares for aggregating the price indeces.
   We will use one national mean calculated using the 
   bottom 40 percentiles of the population as a reference 
   population [use file HHEXPPCS?]
;
gen a= 0 if item~=.;
replace a=totexp if (item<1204 | item>1207) & item ~=.;
egen totfood=sum(a), by(hhnum);
gen fshare=totexp/totfood if (item<1204 | item>1207) & item~=.;
drop a;

gen a=0 if item~=.;
replace a=totexp if item>=1204 & item<=1207;
egen totalch=sum(a), by(hhnum);
replace fshare=totexp/totalch if item>=1204 & item<=1207 & item ~=.;
drop a;

** Save temporary results to use later for caloric consumption etc.
;
save foodexp0, old replace;
des;
sum;


*****************************************
** Collapse to GROUP ITEM AND HH level **
*****************************************
;
egen foodexp=sum(totexp), by(hhnum g_item);

** Recalibrate shares by category groups
;
** Note by Carlo: If budget shares are rescaled the results are right
                  but the averages are not equal to 1.
                  The best approach would be to replace missing values 
                  with 1 which is the same thing as adding the 
                  percentages of missing commodities.
                  Using the bottom 40% the averages are equal to 1.
;
egen gfshare=sum(fshare), by(hhnum g_item);

egen gshqrec=sum (sharqrec*fshare/gfshare), by(hhnum g_item);
egen gshqown=sum (sharqown*fshare/gfshare), by(hhnum g_item);

egen  pindhh =sum(pindex*fshare/gfshare), by(hhnum g_item);

sort hhnum g_item;
qui by hhnum g_item: gen a=_n;
keep if a==1;
drop a;

lab var g_item  "Group item";
lab var foodexp "Food group monthly expenditure";
lab var pindhh  "Price index Hh weight";

lab var gshqown "Share from Own Production";
lab var gshqrec "Share from Other Sources";
lab var gfshare "Food expenditure share";

keep hhnum g_item foodexp g* pind* dist loc_ty;
drop pindex;

format foodexp %7.2f;
format pind* %5.2f;

lab data "Food Exp.";
save hhexpf,replace;
des;
sum;

** Clean up
;


log close;
